<template>
  <div class="chart-wraper">
    <div class="chart" ref="chartContainer"></div>
  </div>
</template>

<script setup>
import * as echarts from "echarts";
import "./theme/custom";

import { onMounted, ref, watchEffect, nextTick, onBeforeUnmount } from "vue";

const props = defineProps({
  unit: {
    type: String,
  },
});

const chartContainer = ref(null);
let myChart = null;
let color = ["#0E7CE2", "#E271DE", "#00FFFF", "#F8456B", "#4AEAB0", "#FF8352"];

function getLinearColor(color0, color1) {
  return {
    type: "linear",
    x: 0,
    y: 0,
    x2: 0,
    y2: 1,
    colorStops: [
      {
        offset: 0,
        color: color0, // 0% 处的颜色
      },
      {
        offset: 1,
        color: color1, // 100% 处的颜色
      },
    ],
  };
}

function getOptions(xLabels = [], datas = []) {
  let barColor = getLinearColor("#7bda59", "#059789");
  let maxColor = getLinearColor("#e3352b", "#f09f2e");
  let minColor = getLinearColor("#f09f2e", "#d3c209");
  return {
    grid: {
      left: 60,
      right: "1%",
      bottom: 30
    },
    tooltip: {
      trigger: "axis",
      axisPointer: {
        // type: "shadow",
        type: "line",
        width: 1,
        color: "#0ff",
      },
    },
    xAxis: {
      type: "category",
      data: xLabels,
    },
    yAxis: {
      type: "value",
      name: props.unit ? `单位: ${props.unit}` : "",
      min: function (data) {
        let min = data.min;
        if (min == Infinity) {
          return 0;
        }
        return Number((min - min * 0.2).toFixed(2));
      },
      max: function (data) {
        let max = data.max;
        if (max == -Infinity) {
          max = 1;
        }
        return Number((max + max * 0.2).toFixed(2));
      },
    },
    series: [
      {
        name: "组端电压",
        type: "line",
        smooth: true,
        symbol: "circle",
        symbolSize: 5,
        showSymbol: false,
        lineStyle: {
          width: 1,
        },
        areaStyle: {
          color: new echarts.graphic.LinearGradient(
            0,
            0,
            0,
            1,
            [
              {
                offset: 0,
                color: "rgba(0, 255, 255, 0.83)",
              },
              {
                offset: 0.8,
                color: "rgba(0, 255, 255, 0.1)",
              },
              {
                offset: 1,
                color: "rgba(0, 0, 0, 0)",
              },
            ]
          ),
          // shadowColor: "rgba(0, 0, 0, 0.1)",
          // shadowBlur: 10,
        },
        itemStyle: {
          color: "#0ff",
          borderColor: "rgba(137,189,2,0.7)",
          borderWidth: 12,
        },
        data: datas
      },
    ],
  };
}

function initChart() {
  if (chartContainer.value) {
    myChart = echarts.init(chartContainer.value, "custom");

    let option = getOptions();
    myChart.setOption(option);

    // 监听窗口变化重新渲染图表
    window.addEventListener("resize", () => {
      myChart.resize();
    });
  }
}

function updateChart(xLabels, datas) {
  let option = getOptions(xLabels, datas);
  myChart.setOption(option);
}

onMounted(() => {
  initChart();
});

watchEffect(() => {
  // 如果需要基于某些响应式数据更新图表，可以在这里处理
});

onBeforeUnmount(() => {
  if (myChart) {
    myChart.dispose();
  }
});

defineExpose({
  updateChart,
});
</script>

<style scoped lang="scss">
.chart-wraper {
  height: 100%;
  position: relative;
  .chart {
    position: absolute;
    left: 0;
    top: 0;
    right: 0;
    bottom: 0;
  }
}
</style>
